@@ -21,7 +21,7 @@ use base 'Apache2::WebApp::Plugin';
 use Apache2::Cookie;
 use Params::Validate qw( :all );
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~[  OBJECT METHODS  ]~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
 
@@ -144,7 +144,7 @@ This package is part of a larger distribution and was NOT intended to be used
 directly.  In order for this plugin to work properly, the following packages
 must be installed:
 
-  Apache2::WebApp::Toolkit
+  Apache2::WebApp
   Apache2::WebApp::Plugin::Filters
   Params::Validate
 
